<?php

namespace Litecms\BusLists\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\BusLists\Interfaces\BusListsRepositoryInterface;

class BusListsPublicController extends BaseController
{
    // use BusListsWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\BusLists\Interfaces\BusListsRepositoryInterface $bus_lists
     *
     * @return type
     */
    public function __construct(BusListsRepositoryInterface $bus_lists)
    {
        $this->repository = $bus_lists;
        parent::__construct();
    }

    /**
     * Show bus_lists's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $bus_lists = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$bus_lists::$bus_lists.names'))
            ->view('$bus_lists::public.bus_lists.index')
            ->data(compact('$bus_lists'))
            ->output();
    }

    /**
     * Show bus_lists's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $bus_lists = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$bus_lists::$bus_lists.names'))
            ->view('$bus_lists::public.bus_lists.index')
            ->data(compact('$bus_lists'))
            ->output();
    }

    /**
     * Show bus_lists.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $bus_lists = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$bus_lists->name . trans('$bus_lists::$bus_lists.name'))
            ->view('$bus_lists::public.bus_lists.show')
            ->data(compact('$bus_lists'))
            ->output();
    }

}
